#!/usr/bin/env python3
import configparser
import os
import sys
import itertools
import argparse
import subprocess
import argcomplete
import functools
import shlex

def completercommand(command, prefix, parsed_args, **kwargs):
    env = os.environ.copy()
    del env["_ARGCOMPLETE"]
    outputs = subprocess.check_output(command.format(**vars(parsed_args)), shell=True, env=env)
    outputs = outputs.decode('utf8')
    outputs = outputs.split('\n')[:-1]
    return (output for output in outputs if output.startswith(prefix))

def main():
    wrapcrc = configparser.ConfigParser()
    wrapcrc.read(os.path.expanduser('~/.wrapcrc'))
    config = wrapcrc[os.path.basename(sys.argv[0])]

    parser = argparse.ArgumentParser()
    for i in itertools.count(start=0, step=1):
        complete = 'complete{}'.format(i)
        if complete in config:
            command = config[complete + "_command"]
            completer = functools.partial(completercommand, command)
            parser.add_argument(config[complete], help=config[complete]).completer = completer
        else:
            break

    argcomplete.autocomplete(parser)
    args, unknownargs = parser.parse_known_args()

    argsdict = vars(args)
    command = shlex.split(config["command"].format(**argsdict))

    os.system(config["pre_hook"].format(**argsdict))

    os.execvp(command[0], command + unknownargs)



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['wrapc']
install_requires = \
['argcomplete>=1.12.3,<2.0.0', 'argparse>=1.4.0,<2.0.0']

entry_points = \
{'console_scripts': ['wrapc = wrapc:main']}

setup_kwargs = {
    'name': 'wrapc',
    'version': '0.0.2',
    'description': 'Wrapper script for starting a command line tool with bash completion',
    'long_description': None,
    'author': 'Dick Marinus',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
